
ALTER SESSION SET CURRENT_SCHEMA= &&RIASSET;


GRANT REFERENCES ON &&NF_SCHEMA..PROJECT TO &&RIASSET;
GRANT REFERENCES ON &&NF_SCHEMA..TEAM TO &&RIASSET;
GRANT REFERENCES ON &&NF_SCHEMA.."RESOURCE" TO &&RIASSET;
GRANT REFERENCES ON &&NF_SCHEMA..REQUIREMENT TO &&RIASSET;
GRANT REFERENCES ON &&NF_SCHEMA..REQUEST TO &&RIASSET;
GRANT REFERENCES ON &&NF_SCHEMA..TESTPLAN TO &&RIASSET;
GRANT REFERENCES ON &&NF_SCHEMA..TESTCASE TO &&RIASSET;

CREATE TABLE ACTION_TYPE(
	ACTION_TYPE_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(50),
	EXTERNAL_ID VARCHAR(100),
	NAME VARCHAR(255) DEFAULT 'Action Name Missing' NOT NULL,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_ROLE (
	ASSET_ROLE_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(50),
	EXTERNAL_ID VARCHAR(100),
	NAME VARCHAR(255) DEFAULT 'Asset Role Name Missing' NOT NULL,
	PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_ROLE_RESOURCE_LOOKUP (
	ASSET_ROLE_ID INTEGER NOT NULL,
	RESOURCE_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_ROLE_TEAM_LOOKUP (
	ASSET_ROLE_ID INTEGER NOT NULL,
	TEAM_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_ROLE_ASSIGNMENT_HISTORY (
	HISTORY_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(50),
	EXTERNAL_ID VARCHAR(100),
  	ASSET_ROLE_ID INTEGER DEFAULT -1 NOT NULL,
  	PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
  	TEAM_ID INTEGER DEFAULT -1 NOT NULL,
  	ASSIGNEE_ID INTEGER DEFAULT -1 NOT NULL,
  	ASSIGNER_ID INTEGER DEFAULT -1 NOT NULL,
  	ACTION_TYPE_ID INTEGER DEFAULT -1 NOT NULL,
  	ASSIGNMENT_DATE TIMESTAMP,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;

CREATE TABLE ENTITLEMENT (
	ENTITLEMENT_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(50),
	EXTERNAL_ID VARCHAR(100),
	NAME VARCHAR(255) DEFAULT 'Entitlement Name Missing' NOT NULL,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;

CREATE TABLE ENTITLEMENT_HISTORY (
	HISTORY_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(50),
	EXTERNAL_ID VARCHAR(100),
  	ASSET_ROLE_ID INTEGER DEFAULT -1 NOT NULL,
  	ACTION_TYPE_ID INTEGER DEFAULT -1 NOT NULL,
  	CHANGE_DATE TIMESTAMP,
  	RESOURCE_ID INTEGER DEFAULT -1 NOT NULL,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;


CREATE TABLE ENTITLEMENT_HISTORY_LOOKUP (
	HISTORY_ID INTEGER NOT NULL,
  	ENTITLEMENT_ID INTEGER NOT NULL,
  	ENTITLEMENT_TYPE VARCHAR(255) NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_ROLE_ENTITLEMENT_LOOKUP(
	ASSET_ROLE_ID INTEGER NOT NULL,
	ENTITLEMENT_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_LOOKUP(
	PRED_ASSET_ID INTEGER NOT NULL,
	SUCC_ASSET_ID INTEGER NOT NULL,
	LINK_TYPE VARCHAR(255)
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_TYPE (
	ASSET_TYPE_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(80),
	EXTERNAL_ID VARCHAR(100),
	NAME VARCHAR(255) DEFAULT 'Asset Type Name Missing' NOT NULL,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
    EXTERNAL_KEY2 CHAR(80) DEFAULT '-1' NOT NULL,             
    SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
    URL VARCHAR(2048),                                        
    REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
    ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET (
	ASSET_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(80),
	EXTERNAL_ID VARCHAR(100),
	NAME VARCHAR(255) DEFAULT 'Asset Name Missing' NOT NULL,
	PROJECT_ID INTEGER DEFAULT -1 NOT NULL,
	VERSION VARCHAR(255),
	ASSET_TYPE_ID INTEGER DEFAULT -1 NOT NULL,
	ASSET_STATE VARCHAR(255),
	LAST_MODIFIED TIMESTAMP,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(80) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_RESOURCE_LOOKUP(
	ASSET_ID INTEGER NOT NULL,
	OWNER_ID INTEGER NOT NULL
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_HISTORY (
	HISTORY_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(50),
	EXTERNAL_ID VARCHAR(100),
	ASSET_ID INTEGER NOT NULL,
  	ACTION_TYPE_ID INTEGER DEFAULT -1 NOT NULL,
  	RESOURCE_ID INTEGER DEFAULT -1 NOT NULL,
  	ACTION_DATE TIMESTAMP,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;
		                          
CREATE TABLE LICENSE_HISTORY (
	HISTORY_ID INTEGER NOT NULL,
	REFERENCE_ID VARCHAR(50),
	EXTERNAL_ID VARCHAR(100),
  	ASSET_ID INTEGER DEFAULT -1 NOT NULL,
  	ACTION_TYPE_ID INTEGER DEFAULT -1 NOT NULL,
  	USAGE_DATE TIMESTAMP,
  	RESOURCE_ID INTEGER DEFAULT -1 NOT NULL,
	EXTERNAL_KEY1 INTEGER DEFAULT -1 NOT NULL,                    
  	EXTERNAL_KEY2 CHAR(40) DEFAULT '-1' NOT NULL,             
  	SOURCE_ID VARCHAR(36) DEFAULT '-1' NOT NULL,              
  	URL VARCHAR(2048),                                        
  	REC_DATETIME TIMESTAMP DEFAULT CURRENT_TIMESTAMP NOT NULL,
  	ISSOFTDELETED SMALLINT DEFAULT 0 NOT NULL                 
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_REQUEST_LOOKUP(
	ASSET_ID INTEGER NOT NULL,
	REQUEST_ID INTEGER NOT NULL,
	LINK_TYPE VARCHAR(255)
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_TESTCASE_LOOKUP(
	ASSET_ID INTEGER NOT NULL,
	TESTCASE_ID INTEGER NOT NULL,
	LINK_TYPE VARCHAR(255)
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_TESTPLAN_LOOKUP(
	ASSET_ID INTEGER NOT NULL,
	TESTPLAN_ID INTEGER NOT NULL,
	LINK_TYPE VARCHAR(255)
) TABLESPACE VNF_32K ;

CREATE TABLE ASSET_REQUIREMENT_LOOKUP(
	ASSET_ID INTEGER NOT NULL,
	REQUIREMENT_ID INTEGER NOT NULL,
	LINK_TYPE VARCHAR(255)
) TABLESPACE VNF_32K ;

-- INDEXES

CREATE INDEX ACTTYPE_IDX3 ON ACTION_TYPE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETTP_IDX3 ON ASSET_TYPE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSET_IDX3 ON ASSET (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETHIST_IDX3 ON ASSET_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETROLE_IDX3 ON ASSET_ROLE (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETRLASSIH_IDX3 ON ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITLEMENT_IDX3 ON ENTITLEMENT (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITHST_IDX3 ON ENTITLEMENT_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LICENSEH_IDX3 ON LICENSE_HISTORY (EXTERNAL_KEY2) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX ACTTYPE_IDX4 ON ACTION_TYPE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETTP_IDX4 ON ASSET_TYPE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSET_IDX4 ON ASSET (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETHIST_IDX4 ON ASSET_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETROLE_IDX4 ON ASSET_ROLE (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETRLASSIH_IDX4 ON ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITLEMENT_IDX4 ON ENTITLEMENT (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITHST_IDX4 ON ENTITLEMENT_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LICENSEH_IDX4 ON LICENSE_HISTORY (EXTERNAL_KEY1,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX ACTTYPE_IDX5 ON ACTION_TYPE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETTP_IDX5 ON ASSET_TYPE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSET_IDX5 ON ASSET (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETHIST_IDX5 ON ASSET_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETROLE_IDX5 ON ASSET_ROLE (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETRLASSIH_IDX5 ON ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITLEMENT_IDX5 ON ENTITLEMENT (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITHST_IDX5 ON ENTITLEMENT_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LICENSEH_IDX5 ON LICENSE_HISTORY (EXTERNAL_KEY2,SOURCE_ID) REVERSE TABLESPACE VNF_IDX;

CREATE INDEX ACTTYPE_IDX2 ON ACTION_TYPE (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETTP_IDX2 ON ASSET_TYPE (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSET_IDX2 ON ASSET (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETHIST_IDX2 ON ASSET_HISTORY (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETROLE_IDX2 ON ASSET_ROLE (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ASSETRLASSIH_IDX2 ON ASSET_ROLE_ASSIGNMENT_HISTORY (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITLEMENT_IDX2 ON ENTITLEMENT (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX ENTITHST_IDX2 ON ENTITLEMENT_HISTORY (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;
CREATE INDEX LICENSEH_IDX2 ON LICENSE_HISTORY (EXTERNAL_ID) REVERSE TABLESPACE VNF_IDX;


-- PRIMARY KEY CONSTRAINTS
ALTER TABLE ACTION_TYPE ADD CONSTRAINT ACTIONTP_PK PRIMARY KEY (ACTION_TYPE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ASSET_TYPE ADD CONSTRAINT ASSETTP_PK PRIMARY KEY (ASSET_TYPE_ID) USING INDEX TABLESPACE  VNF_IDX; 

ALTER TABLE ASSET ADD CONSTRAINT ASSET_PK PRIMARY KEY (ASSET_ID) USING INDEX TABLESPACE  VNF_IDX;          
                                         
ALTER TABLE ASSET_ROLE ADD CONSTRAINT ASSETROLE_PK PRIMARY KEY (ASSET_ROLE_ID) USING INDEX TABLESPACE  VNF_IDX;      
                              
ALTER TABLE ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_PK PRIMARY KEY (HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX; 

ALTER TABLE ENTITLEMENT ADD CONSTRAINT ENTITLEMENT_PK PRIMARY KEY (ENTITLEMENT_ID) USING INDEX TABLESPACE  VNF_IDX;                          
       
ALTER TABLE ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_PK PRIMARY KEY (HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;            
                     
ALTER TABLE LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_PK PRIMARY KEY (HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;      

ALTER TABLE ASSET_ROLE_ENTITLEMENT_LOOKUP ADD CONSTRAINT ASSERLENTLK_PK PRIMARY KEY (ASSET_ROLE_ID,ENTITLEMENT_ID) USING INDEX TABLESPACE  VNF_IDX; 

ALTER TABLE ASSET_LOOKUP ADD CONSTRAINT ASSETLKUP_PK PRIMARY KEY (PRED_ASSET_ID,SUCC_ASSET_ID) USING INDEX TABLESPACE  VNF_IDX;                          
          
ALTER TABLE ASSET_RESOURCE_LOOKUP ADD CONSTRAINT ASSERESLK_PK PRIMARY KEY (ASSET_ID,OWNER_ID) USING INDEX TABLESPACE  VNF_IDX;                  
          
ALTER TABLE ASSET_REQUEST_LOOKUP ADD CONSTRAINT ASSEREQULK_PK PRIMARY KEY (ASSET_ID,REQUEST_ID) USING INDEX TABLESPACE  VNF_IDX;           
                 
ALTER TABLE ASSET_TESTCASE_LOOKUP ADD CONSTRAINT ASSETCASELK_PK PRIMARY KEY (ASSET_ID,TESTCASE_ID) USING INDEX TABLESPACE  VNF_IDX;        
                 
ALTER TABLE ASSET_TESTPLAN_LOOKUP ADD CONSTRAINT ASSETPLANLK_PK PRIMARY KEY (ASSET_ID,TESTPLAN_ID) USING INDEX TABLESPACE  VNF_IDX; 

ALTER TABLE ENTITLEMENT_HISTORY_LOOKUP ADD CONSTRAINT ENTHISTLK_PK PRIMARY KEY (HISTORY_ID,ENTITLEMENT_ID,ENTITLEMENT_TYPE) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ASSET_ROLE_RESOURCE_LOOKUP ADD CONSTRAINT ASSETRLRESLK_PK PRIMARY KEY (ASSET_ROLE_ID,RESOURCE_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ASSET_ROLE_TEAM_LOOKUP ADD CONSTRAINT ASSETRLTEAMLK_PK PRIMARY KEY (ASSET_ROLE_ID,TEAM_ID) USING INDEX TABLESPACE  VNF_IDX;

ALTER TABLE ASSET_HISTORY ADD CONSTRAINT ASSETHIST_PK PRIMARY KEY (HISTORY_ID) USING INDEX TABLESPACE  VNF_IDX;




--FOREIGN KEY

ALTER TABLE ASSET ADD CONSTRAINT ASSET_FK1 FOREIGN KEY (PROJECT_ID) 
	REFERENCES  &&NF_SCHEMA..PROJECT (PROJECT_ID) ;  
	                                                                 
ALTER TABLE ASSET ADD CONSTRAINT ASSET_FK2 FOREIGN KEY (ASSET_TYPE_ID) 
	REFERENCES ASSET_TYPE (ASSET_TYPE_ID) ;  
	                                                                 
ALTER TABLE ASSET_ROLE ADD CONSTRAINT ASSETROLE_FK1 FOREIGN KEY (PROJECT_ID) 
	REFERENCES  &&NF_SCHEMA..PROJECT (PROJECT_ID) ; 
	                                                    
ALTER TABLE ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK1 FOREIGN KEY (ASSET_ROLE_ID) 
	REFERENCES ASSET_ROLE (ASSET_ROLE_ID) ; 
	
ALTER TABLE ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK2 FOREIGN KEY (PROJECT_ID) 
	REFERENCES  &&NF_SCHEMA..PROJECT (PROJECT_ID) ;   
	       
ALTER TABLE ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK3 FOREIGN KEY (TEAM_ID) 
	REFERENCES  &&NF_SCHEMA..TEAM (TEAM_ID) ;          
	         
ALTER TABLE ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK4 FOREIGN KEY (ASSIGNEE_ID) 
	REFERENCES  &&NF_SCHEMA.."RESOURCE" (RESOURCE_ID) ;  
	     
ALTER TABLE ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK5 FOREIGN KEY (ASSIGNER_ID) 
	REFERENCES  &&NF_SCHEMA.."RESOURCE" (RESOURCE_ID) ;
	
ALTER TABLE ASSET_ROLE_ASSIGNMENT_HISTORY ADD CONSTRAINT ASSETRLASSIH_FK6 FOREIGN KEY (ACTION_TYPE_ID) 
	REFERENCES ACTION_TYPE (ACTION_TYPE_ID) ;		 
	      
ALTER TABLE ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_FK1 FOREIGN KEY (ASSET_ROLE_ID) 
	REFERENCES ASSET_ROLE (ASSET_ROLE_ID) ;   
	    
ALTER TABLE ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_FK2 FOREIGN KEY (RESOURCE_ID) 
	REFERENCES  &&NF_SCHEMA.."RESOURCE" (RESOURCE_ID) ;    
	
ALTER TABLE ENTITLEMENT_HISTORY ADD CONSTRAINT ENTITLEHIST_FK3 FOREIGN KEY (ACTION_TYPE_ID) 
	REFERENCES ACTION_TYPE (ACTION_TYPE_ID) ; 	  
	                     
ALTER TABLE LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_FK1 FOREIGN KEY (ASSET_ID) 
	REFERENCES ASSET (ASSET_ID) ;            
	                                
ALTER TABLE LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_FK2 FOREIGN KEY (RESOURCE_ID) 
	REFERENCES  &&NF_SCHEMA.."RESOURCE" (RESOURCE_ID) ;  
	
ALTER TABLE LICENSE_HISTORY ADD CONSTRAINT LICENSEHIST_FK3 FOREIGN KEY (ACTION_TYPE_ID) 
	REFERENCES ACTION_TYPE (ACTION_TYPE_ID) ;	                                 
                 
ALTER TABLE ASSET_LOOKUP ADD CONSTRAINT ASSETLKUP_FK1 FOREIGN KEY (PRED_ASSET_ID) 
	REFERENCES ASSET (ASSET_ID) ;  
	                                    
ALTER TABLE ASSET_LOOKUP ADD CONSTRAINT ASSETLKUP_FK2 FOREIGN KEY (SUCC_ASSET_ID) 
	REFERENCES ASSET (ASSET_ID) ;
	                                      
ALTER TABLE ASSET_REQUEST_LOOKUP ADD CONSTRAINT ASSEREQULK_FK1 FOREIGN KEY (ASSET_ID) 
	REFERENCES ASSET (ASSET_ID) ;      
	                               
ALTER TABLE ASSET_REQUEST_LOOKUP ADD CONSTRAINT ASSEREQULK_FK2 FOREIGN KEY (REQUEST_ID) 
	REFERENCES  &&NF_SCHEMA..REQUEST (REQUEST_ID) ;   
	                            
ALTER TABLE ASSET_RESOURCE_LOOKUP ADD CONSTRAINT ASSERESLK_FK1 FOREIGN KEY (ASSET_ID) 
	REFERENCES ASSET (ASSET_ID) ;     
	                              
ALTER TABLE ASSET_RESOURCE_LOOKUP ADD CONSTRAINT ASSERESLK_FK2 FOREIGN KEY (OWNER_ID) 
	REFERENCES  &&NF_SCHEMA.."RESOURCE" (RESOURCE_ID) ;  
	                                 
ALTER TABLE ASSET_ROLE_ENTITLEMENT_LOOKUP ADD CONSTRAINT ASSERLENTLK_FK1 FOREIGN KEY (ASSET_ROLE_ID) 
	REFERENCES ASSET_ROLE(ASSET_ROLE_ID) ;  
	  
ALTER TABLE ASSET_ROLE_ENTITLEMENT_LOOKUP ADD CONSTRAINT ASSERLENTLK_FK2 FOREIGN KEY (ENTITLEMENT_ID) 
	REFERENCES ENTITLEMENT (ENTITLEMENT_ID) ; 
	
ALTER TABLE ASSET_TESTCASE_LOOKUP ADD CONSTRAINT ASSETCASELK_FK1 FOREIGN KEY (ASSET_ID) 
	REFERENCES ASSET (ASSET_ID) ;        
	                           
ALTER TABLE ASSET_TESTCASE_LOOKUP ADD CONSTRAINT ASSETCASELK_FK2 FOREIGN KEY (TESTCASE_ID) 
	REFERENCES  &&NF_SCHEMA..TESTCASE (TESTCASE_ID) ; 
	                         
ALTER TABLE ASSET_TESTPLAN_LOOKUP ADD CONSTRAINT ASSETPLANLK_FK1 FOREIGN KEY (ASSET_ID) 
	REFERENCES ASSET (ASSET_ID) ;              
	                     
ALTER TABLE ASSET_TESTPLAN_LOOKUP ADD CONSTRAINT ASSETPLANLK_FK2 FOREIGN KEY (TESTPLAN_ID) 
	REFERENCES  &&NF_SCHEMA..TESTPLAN (TESTPLAN_ID) ;   
	
ALTER TABLE ENTITLEMENT_HISTORY_LOOKUP ADD CONSTRAINT ENTHISTLK_FK1 FOREIGN KEY (HISTORY_ID)
	REFERENCES ENTITLEMENT_HISTORY (HISTORY_ID);	 
	
ALTER TABLE ENTITLEMENT_HISTORY_LOOKUP ADD CONSTRAINT ENTHISTLK_FK2 FOREIGN KEY (ENTITLEMENT_ID)
	REFERENCES ENTITLEMENT (ENTITLEMENT_ID);	    
	
ALTER TABLE ASSET_ROLE_RESOURCE_LOOKUP ADD CONSTRAINT ASSETRLRESLK_FK1 FOREIGN KEY (ASSET_ROLE_ID)
	REFERENCES ASSET_ROLE (ASSET_ROLE_ID);
	
ALTER TABLE ASSET_ROLE_RESOURCE_LOOKUP ADD CONSTRAINT ASSETRLRESLK_FK2 FOREIGN KEY (RESOURCE_ID)
	REFERENCES  &&NF_SCHEMA.."RESOURCE";	

ALTER TABLE ASSET_ROLE_TEAM_LOOKUP ADD CONSTRAINT ASSETRLTEAMLK_FK1 FOREIGN KEY (ASSET_ROLE_ID)
	REFERENCES ASSET_ROLE (ASSET_ROLE_ID);	
	
ALTER TABLE ASSET_ROLE_TEAM_LOOKUP ADD CONSTRAINT ASSETRLTEAMLK_FK2 FOREIGN KEY (TEAM_ID)
	REFERENCES  &&NF_SCHEMA..TEAM (TEAM_ID);		
	
ALTER TABLE ASSET_HISTORY ADD CONSTRAINT ASSETHIST_FK1 FOREIGN KEY (ASSET_ID)
	REFERENCES ASSET (ASSET_ID);	    

ALTER TABLE ASSET_HISTORY ADD CONSTRAINT ASSETHIST_FK2 FOREIGN KEY (ACTION_TYPE_ID)
	REFERENCES ACTION_TYPE (ACTION_TYPE_ID);
	
ALTER TABLE ASSET_HISTORY ADD CONSTRAINT ASSETHIST_FK3 FOREIGN KEY (RESOURCE_ID)
	REFERENCES  &&NF_SCHEMA.."RESOURCE" (RESOURCE_ID);		               
                 
--TRIGGERS


CREATE TRIGGER TRG_ASSETLK
	AFTER UPDATE OF REC_DATETIME ON ASSET
	FOR EACH ROW                                                       
BEGIN                                                                           

    DELETE FROM ASSET_LOOKUP WHERE (PRED_ASSET_ID=:NEW.ASSET_ID OR SUCC_ASSET_ID=:NEW.ASSET_ID); 
END;
/

    
CREATE TRIGGER TRG_ASSREQUELK	                           
 AFTER UPDATE OF REC_DATETIME ON ASSET                                                                         
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_REQUEST_LOOKUP WHERE ASSET_ID=:NEW.ASSET_ID; 
END;
/                                                                                          


CREATE TRIGGER TRG_ASSRESOULK 
 AFTER UPDATE OF REC_DATETIME ON ASSET                                                                      
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_RESOURCE_LOOKUP WHERE ASSET_ID=:NEW.ASSET_ID; 
END;
/      


CREATE TRIGGER TRG_ASSENTITLK 
 AFTER UPDATE OF REC_DATETIME ON ASSET_ROLE                                                                   
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_ROLE_ENTITLEMENT_LOOKUP WHERE ASSET_ROLE_ID=:NEW.ASSET_ROLE_ID; 
END;
/ 


CREATE TRIGGER TRG_ASSTSTCASELK 
 AFTER UPDATE OF REC_DATETIME ON ASSET                                                                         
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_TESTCASE_LOOKUP WHERE ASSET_ID=:NEW.ASSET_ID; 
END;
/  


CREATE TRIGGER TRG_TSTPLNLK 
 AFTER UPDATE OF REC_DATETIME ON ASSET                                                                          
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_TESTPLAN_LOOKUP WHERE ASSET_ID=:NEW.ASSET_ID; 
END;
/

    
CREATE TRIGGER TRG_ASSRLRESELK 
 AFTER UPDATE OF REC_DATETIME ON ASSET_ROLE                                                                        
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_ROLE_RESOURCE_LOOKUP WHERE ASSET_ROLE_ID=:NEW.ASSET_ROLE_ID; 
END;
/    

      
CREATE TRIGGER TRG_ASSRLTEAMLK 
 AFTER UPDATE OF REC_DATETIME ON ASSET_ROLE                                                                        
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_ROLE_TEAM_LOOKUP WHERE ASSET_ROLE_ID=:NEW.ASSET_ROLE_ID; 
END;
/ 


CREATE TRIGGER TRG_ASSREQUILK 
 AFTER UPDATE OF REC_DATETIME ON ASSET                                                                      
	FOR EACH ROW                                                              
BEGIN                                                                           

    DELETE FROM ASSET_REQUIREMENT_LOOKUP WHERE ASSET_ID=:NEW.ASSET_ID; 
END;
/

      